require_dependency "radesk/application_controller"

module Radesk
  class AnswersController < ApplicationController
    include Radesk::ActivitiesHelper
    
    before_action :radesk_authorize!
    before_action :set_answer, only: [:edit, :update, :destroy]
    before_filter -> { radesk_check_access(@answer) }, only: [:edit, :update, :destroy]

    def create
      @answer = Answer.new(answer_params)
      @answer.user_id = radesk_current_user.id
      @answer.ticket_id = params[:ticket_id]

      if @answer.save
        UserMailer.new_answer(@answer).deliver_now
        add_activity(@answer, 'create')
        redirect_to @answer.ticket, notice: 'Answer was successfully created.'
      else
        redirect_to :back, notice: @answer.errors.full_messages.first
      end
    end

    def edit
    end

    def update
      if @answer.update(answer_params)
        add_activity(@answer, 'update')
        redirect_to @answer.ticket, notice: 'Answer was successfully updated.'
      else
        render :edit
      end
    end

    def destroy
      @answer.destroy
      redirect_to @answer.ticket, notice: 'Answer was successfully destroyed.'
    end

    private
      def set_answer
        @answer = Answer.find(params[:id])
      end

      def answer_params
        params.require(:answer).permit(:message, :private, :uploads_attributes => [:id, :file])
      end
  end
end
