require_dependency "radesk/application_controller"

module Radesk
  class TicketsController < ApplicationController
    include Radesk::ActivitiesHelper
    include Radesk::HipchatHelper

    if Radesk.elasticsearch
      include Radesk::Concerns::Elasticsearch
    else
      include Radesk::Concerns::Nosearch
    end
    
    before_action :radesk_authorize!
    before_action :set_ticket, only: [:show, :edit, :update, :destroy, :open, :close]
    before_filter -> { radesk_check_access(@ticket) }, only: [:show, :edit, :update, :destroy, :open, :close]

    def show
      @answers = @ticket.answers.includes(Radesk.user_class_name.downcase.to_sym)
      unless radesk_current_user.try(:radesk_admin?)
        @answers = @answers.without_private
      end
    end

    def new
      @ticket = Ticket.new
      @ticket.answers.build
    end

    def create
      @ticket = Ticket.new(ticket_params)
      @ticket.user_id = radesk_current_user.id
      @ticket.answers.first.user = radesk_current_user

      if @ticket.save
        add_activity(@ticket, 'create')
        send_notification(@ticket)
        redirect_to @ticket, notice: 'Ticket was successfully created.'
      else
        render :new
      end
    end

    def edit
    end

    def update
      if @ticket.update(ticket_params)
        add_activity(@ticket, 'update')
        redirect_to @ticket, notice: 'Ticket was successfully updated.'
      else
        render :edit
      end
    end

    def destroy
      @ticket.destroy
      redirect_to tickets_url, notice: 'Ticket was successfully destroyed.'
    end

    def open
      @ticket.update(:closed => false)
      add_activity(@ticket, 'open')
      render 'update_status'
    end

    def close
      @ticket.update(:closed => true)
      add_activity(@ticket, 'close')
      render 'update_status'
    end

    private
      def set_ticket
        @ticket = Ticket.find(params[:id])
      end

      def ticket_params
        params.require(:ticket).permit(:title, :message, :closed, :category_id, :answers_attributes => [:id, :message])
      end
  end
end
